;**************************************************************************
;*                    Test SW - 433MHz Transmission                       *
;**************************************************************************
;**************************************************************************
;*                                                                        *
;*          PT2272 remote control replacement                             *
;*          v 1.11 - 16.09.2017                                           *
;*                                                                        *
;**************************************************************************
;*          Hardw.: PIC12F1822 used                                       *
;*          OSC.......: Internal osc. used     POWER.....:   5V extern.   *
;**************************************************************************


;Vss (Pin 8) -- GND
;RA0 (Pin 7) -- Power Swtich for the Transmitter module -- not used in current prototype
;RA1 (Pin 6) -- Light ON
;RA2 (Pin 5) -- Transmitter
;RA3 (Pin 4) -- 
;RA4 (Pin 3) -- Light OFF
;RA5 (Pin 2) -- Test LED
;Vdd (Pin 1) -- +5V




 INCLUDE "P12F1822.INC"


_U001			     EQU     B'00100110000100'		;see Page 50 of Datasheet
_U002			     EQU     B'01100011111111'		;see Page 52 of Datasheet


	__CONFIG	_CONFIG1, _U001
	__CONFIG	_CONFIG2, _U002


;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'20'		;delay routine
TIMER2		EQU	H'21'		; "	"	"

v_tmp1		EQU	H'22'
v_value		EQU	H'23'		;value of the ports from PCF8574

v_w1		EQU	H'24'
v_w2		EQU	H'25'

v_t1		EQU	H'26'
v_t2		EQU	H'27'
v_t3		EQU	H'28'
v_t4		EQU	H'29'
;--------------------------------------------------------------------------
;--------------------------------------------------------------------------


;==========================================================================

		ORG	0		;Reset vector address
		goto	start

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

start		nop
;
		clrf	INTCON		;disable interrupts

		banksel	OPTION_REG
		movlw	B'00000000'
		movwf	OPTION_REG

		movlw	H'03'
		movwf	BSR		;select BANK 3
		clrf	ANSELA

		movlw	H'01'
		movwf	BSR		;select BANK 1
		movlw	B'11010010'
		movwf	TRISA

		banksel	WPUA
		movlw	B'00010010'
		movwf	WPUA

		banksel	OSCCON
		movlw	B'01110000'
		movwf	OSCCON		;set 8 MHz internal clock (default after reset is 500kHz)

		clrf	BSR		;select BANK 0

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;Main loop
		movlw	B'00000001'
		movwf	PORTA

main_loop2	bsf	PORTA,D'000'		;TX off
;---------------------------------------------
main_loop	btfss	PORTA,D'001'
		goto	send_on			;Light ON
		
		btfss	PORTA,D'004'
		goto	send_off		;Light OFF
	
		goto	main_loop2
;---------------------------------------------

;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
send_on		bcf	PORTA,D'002'		;Data Line to 0
		bsf	PORTA,D'005'		;LED on
		bcf	PORTA,D'000'		;TX on

		call	tx_send_on1

		bcf	PORTA,D'005'		;LED off
		bcf	PORTA,D'002'		;Data Line to 0
		goto	main_loop	
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
send_off	bcf	PORTA,D'002'		;Data Line to 0
		bsf	PORTA,D'005'		;LED on
		bcf	PORTA,D'000'		;TX on

		call	tx_send_off1

		bcf	PORTA,D'005'		;LED off
		bcf	PORTA,D'002'		;Data Line to 0
		goto	main_loop	
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;timing is implemented for kwmobile model # 40809 / 0302-3
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------

tx_send_F	nop
;(01)
		bsf	PORTA,D'002'
		call	wait_200
;(02)
		bcf	PORTA,D'002'
		call	wait_600
;(03)
		bsf	PORTA,D'002'
		call	wait_600
;(04)
		bcf	PORTA,D'002'
		call	wait_200
;
		return
;-------------------------------------------------------------------------------
tx_send_0	nop
;(01)
		bsf	PORTA,D'002'
		call	wait_200
;(02)
		bcf	PORTA,D'002'
		call	wait_600
;(03)
		bsf	PORTA,D'002'
		call	wait_200
;(04)
		bcf	PORTA,D'002'
		call	wait_600
;
		return
;-------------------------------------------------------------------------------
tx_send_1	nop
;(01)
		bsf	PORTA,D'002'
		call	wait_600
;(02)
		bcf	PORTA,D'002'
		call	wait_200
;(03)
		bsf	PORTA,D'002'
		call	wait_600
;(04)
		bcf	PORTA,D'002'
		call	wait_200
;
		return

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------

tx_send_on1	nop
;keep the line a while in 0
		call	d1
;start transmission
		call	tx_send_F		;A0
		call	tx_send_0		;A1
		call	tx_send_F		;A2
		call	tx_send_F		;A3
		call	tx_send_F		;A4
		call	tx_send_F		;A5
		call	tx_send_F		;A6
		call	tx_send_1		;A7
		call	tx_send_0		;A8
		call	tx_send_0		;A9
		call	tx_send_0		;A10
		call	tx_send_1		;A11
;Finish the transmission
		bsf	PORTA,D'002'
		call	wait_200
		bcf	PORTA,D'002'
		call	d1
;---------------------------------------
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
tx_send_off1	nop
;keep the line a while in 0
		call	d1
;start transmission
		call	tx_send_F		;A0
		call	tx_send_0		;A1
		call	tx_send_F		;A2
		call	tx_send_F		;A3
		call	tx_send_F		;A4
		call	tx_send_F		;A5
		call	tx_send_F		;A6
		call	tx_send_1		;A7
		call	tx_send_0		;A8
		call	tx_send_0		;A9
		call	tx_send_1		;A10
		call	tx_send_0		;A11
;Finish the transmission
		bsf	PORTA,D'002'
		call	wait_200
		bcf	PORTA,D'002'
		call	d1
;---------------------------------------
;---------------------------------------
		return
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

;----------------------------------------------------------
;150us
;----------------------------------------------------------
wait_150	movlw	D'100'
		movwf	TIMER1

w150_il		decfsz	TIMER1,1	;0,50 us (8 MHz)
		goto	w150_il		;1,00 us (8 MHz)

		return
;----------------------------------------------------------
;----------------------------------------------------------
;----------------------------------------------------------
;200us
;----------------------------------------------------------
wait_200	movlw	D'100'
		movwf	TIMER1

w200_il		nop			;0,50 us (8 MHz)
		decfsz	TIMER1,1	;0,50 us (8 MHz)
		goto	w200_il		;1,00 us (8 MHz)

		return
;----------------------------------------------------------
;----------------------------------------------------------
;----------------------------------------------------------
;500us
;----------------------------------------------------------
wait_500	movlw	D'100'
		movwf	TIMER1

w500_il		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 1us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 2us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 3us
		nop			;0,50 us (8 MHz)
		decfsz	TIMER1,1	;0,50 us (8 MHz)	/ 4us

		goto	w500_il		;1,00 us (8 MHz)	/ 5us

		return
;----------------------------------------------------------
;----------------------------------------------------------
;----------------------------------------------------------
;550us
;----------------------------------------------------------
wait_550	movlw	D'100'
		movwf	TIMER1

w550_il		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 1us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 2us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 3us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 4us
		decfsz	TIMER1,1	;0,50 us (8 MHz)

		goto	w550_il		;1,00 us (8 MHz)	/ 5.5us

		return
;----------------------------------------------------------
;----------------------------------------------------------
;----------------------------------------------------------
;600us
;----------------------------------------------------------
wait_600	movlw	D'100'
		movwf	TIMER1

w600_il		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 1us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 2us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 3us
		nop			;0,50 us (8 MHz)
		nop			;0,50 us (8 MHz)	/ 4us
		nop			;0,50 us (8 MHz)
		decfsz	TIMER1,1	;0,50 us (8 MHz)	/ 5us

		goto	w600_il		;1,00 us (8 MHz)	/ 6us

		return
;----------------------------------------------------------
;----------------------------------------------------------

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


d2		movlw	D'255'
		movwf	TIMER2
DEL_LOOP1	movlw	D'255'
		movwf	TIMER1

DEL_LOOP2	decfsz	TIMER1,F
		goto	DEL_LOOP2
		decfsz	TIMER2,F
		goto	DEL_LOOP1
		return
;------------------------------------
dr2		call	d2
		call	d2
		return
;------------------------------------
d1		movlw	D'010'
		movwf	TIMER2
DEL_LOOP11	movlw	D'255'
		movwf	TIMER1

DEL_LOOP12	decfsz	TIMER1,F
		goto	DEL_LOOP12
		decfsz	TIMER2,F
		goto	DEL_LOOP11
		return
;------------------------------------

d55		movlw	D'255'
		movwf	TIMER2
d55_loop	decfsz	TIMER2,F
		goto	d55_loop
		return

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		END